@@ -24,15 +24,21 @@ class CodeGen:
         assert_type(root, ir.Vertex)
         assert_type(context, ir.Context)
         self.context = context
+
+        self.context.output_vars = [
+            ir.Var(str(i)) for i in range(len(self.context.output_types))
+        ]
+
         root_case = CaseBuilder(root, context).case
 
         for item in root_case.case_items:
             self.context.add_state(item.condition.to_string())
 
+        assert isinstance(context.ready_state, str)
         self.context.add_state_weak(context.ready_state)
 
         self.context.add_global_var(
-            ir.InputVar("state", initial_value=self.context.ready_state)
+            ir.Var("state", initial_value=self.context.ready_state)
         )
 
         self._module = CodeGen.__new_module(root_case, self.context)
@@ -120,7 +126,7 @@ class CodeGen:
         init_body = []
 
         for item in root.case_items:
-            if item.condition == ir.Expression(context.entry):
+            if item.condition == ir.Expression(context.entry_state):
                 stmt_stack += item.statements
                 init_body += item.statements
                 root.case_items.remove(item)
@@ -171,12 +177,19 @@ class CodeGen:
         """
         return str(self.get_module_lines())
 
-    def new_testbench(self, test_cases: list[tuple[str]]):
+    def get_testbench(self):
         """
         Creates testbench with multiple test cases
 
-        Each element of test_cases represents a single test case
+        Each element of self.context.test_cases represents a single test case
         """
+        if len(self.context.input_vars) == 0:
+            raise RuntimeError(f"Input var names not deduced for {self.context.name}")
+        if len(self.context.output_vars) == 0:
+            raise RuntimeError(
+                f"Output var types not deduced for {self.context.name}, \
+                    types are {self.context.output_types}"
+            )
 
         def make_display_stmt():
             """
@@ -231,7 +244,7 @@ class CodeGen:
         )
         initial_body.append(ver.Statement())
 
-        for i, test_case in enumerate(test_cases):
+        for i, test_case in enumerate(self.context.test_cases):
             # setup for new test case
             initial_body.append(
                 ver.Statement(comment=f"Test case {i}: {str(test_case)}")
@@ -280,17 +293,17 @@ class CodeGen:
             return module
         raise RuntimeError("Needs the context")
 
-    def new_testbench_lines(self, test_cases: list[tuple[str]]):
+    def get_testbench_lines(self):
         """
         New Testbench as lines
         """
-        return self.new_testbench(test_cases).to_lines()
+        return self.get_testbench().to_lines()
 
-    def new_testbench_str(self, test_cases: list[tuple[str]]):
+    def get_testbench_str(self):
         """
         New testbench as str
         """
-        return str(self.new_testbench_lines(test_cases))
+        return str(self.get_testbench_lines())
 
 
 class CaseBuilder:
