@@ -15,7 +15,7 @@ def is_dependent(expr: ir.Expression, var: str):
     """
     Returns whether or not expr is dependent on var
     """
-    if isinstance(expr, ir.InputVar):
+    if isinstance(expr, ir.Var):
         return var == expr.to_string()
     if isinstance(expr, ir.BinOp):
         return is_dependent(expr.left, var) or is_dependent(expr.right, var)
@@ -26,10 +26,13 @@ def is_dependent(expr: ir.Expression, var: str):
 
 def backwards_replace(expr: ir.Expression, mapping: dict[ir.Expression, ir.Expression]):
     """
-    Replaces instances of variables with the mapped value
+    If the expression matches a key in the mapping, it is replaced with
+    the corresponding value in the mapping.
+
+    :return: a copy of the updated expression.
     """
     expr = copy.deepcopy(expr)
-    if isinstance(expr, ir.InputVar):
+    if isinstance(expr, ir.Var):
         for key in mapping:
             if key.to_string() == expr.to_string():
                 return mapping[key]
@@ -53,7 +56,11 @@ def graph_apply_mapping(
     node: ir.AssignNode, mapping: dict[ir.Expression, ir.Expression]
 ):
     """
-    Replace all rvalues of expressions in stmt with mapping
+    If the right-hand-side of an assignment (e.g. the `b` in `a = b`)
+    matches a key in the mapping, it will be replaced with the
+    corresponding value in the mapping.
+
+    :return: a node with the mapping applied
     """
     try:
         node = copy.copy(node)
